"use strict";

// @ts-check
var browserslist = require("browserslist");

var arrify = require("arrify");

var has = require("lodash.has");

var fs = require("fs");

var readPkgUp = require("read-pkg-up");

var path = require("path"); // @TODO Stop duplicating those utils. Start babel through node instead
// of the cli


var _readPkgUp$sync = readPkgUp.sync({
  cwd: fs.realpathSync(process.cwd())
}),
    pkg = _readPkgUp$sync.pkg,
    pkgPath = _readPkgUp$sync.path;

var appDirectory = path.dirname(pkgPath);

var envIsSet = function (name) {
  return process.env.hasOwnProperty(name) && process.env[name] && process.env[name] !== "undefined";
};

var parseEnv = function (name, def) {
  if (envIsSet(name)) {
    try {
      return JSON.parse(process.env[name]);
    } catch (err) {
      return process.env[name];
    }
  }

  return def;
};

var hasPkgProp = function (props) {
  return arrify(props).some(function (prop) {
    return has(pkg, prop);
  });
};

var hasPkgSubProp = function (pkgProp) {
  return function (props) {
    return hasPkgProp(arrify(props).map(function (p) {
      return `${pkgProp}.${p}`;
    }));
  };
};

var hasPeerDep = hasPkgSubProp("peerDependencies");
var hasDep = hasPkgSubProp("dependencies");
var hasDevDep = hasPkgSubProp("devDependencies");

var hasAnyDep = function (args) {
  return [hasDep, hasDevDep, hasPeerDep].some(function (fn) {
    return fn(args);
  });
};

var ifAnyDep = function (deps, t, f) {
  return hasAnyDep(arrify(deps)) ? t : f;
};

var isTest = (process.env.BABEL_ENV || process.env.NODE_ENV) === "test";
var isRollup = parseEnv("BUILD_ROLLUP", false);
var isUMD = process.env.BUILD_FORMAT === "umd";
var isWebpack = parseEnv("BUILD_WEBPACK", false);
var treeshake = parseEnv("BUILD_TREESHAKE", isRollup || isWebpack);
/**
 * use the strategy declared by browserslist to load browsers configuration.
 * fallback to the default if don't found custom configuration
 * @see https://github.com/browserslist/browserslist/blob/master/node.js#L139
 */

var browsersConfig = browserslist.loadConfig({
  path: appDirectory
}) || ["ie 10", "ios 7"];
var envTargets = isTest ? {
  node: "current"
} : isWebpack || isRollup ? {
  browsers: browsersConfig
} : {
  node: "4.5"
};
var envOptions = {
  modules: false,
  loose: true,
  targets: envTargets
};

module.exports = function () {
  return {
    presets: [require.resolve("@babel/preset-typescript"), [require.resolve("@babel/preset-env"), envOptions], ifAnyDep(["react"], require.resolve("@babel/preset-react"))].filter(Boolean),
    plugins: [isRollup ? require.resolve("@babel/plugin-external-helpers") : null, isUMD ? require.resolve("babel-plugin-transform-inline-environment-variables") : null, [require.resolve("@babel/plugin-proposal-class-properties"), {
      loose: true
    }], require.resolve("@babel/plugin-proposal-object-rest-spread"), require.resolve("babel-plugin-minify-dead-code-elimination"), treeshake ? null : [require.resolve("@babel/plugin-transform-modules-commonjs"), {
      loose: true
    }]].filter(Boolean)
  };
};
//# sourceMappingURL=babelrc.js.map