"use strict";

var _path = _interopRequireDefault(require("path"));

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _glob = _interopRequireDefault(require("glob"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _process$argv = process.argv,
    executor = _process$argv[0],
    ignoredBin = _process$argv[1],
    script = _process$argv[2],
    args = _process$argv.slice(3);

if (script) {
  spawnScript();
} else {
  var scriptsPath = _path.default.join(__dirname, "scripts/");

  var scriptsAvailable = _glob.default.sync(_path.default.join(__dirname, "scripts", "*")); // `glob.sync` returns paths with unix style path separators even on Windows.
  // So we normalize it before attempting to strip out the scripts path.


  var scriptsAvailableMessage = scriptsAvailable.map(_path.default.normalize).map(function (s) {
    return s.replace(scriptsPath, "").replace(/__tests__/, "").replace(/\.ts$/, "");
  }).filter(Boolean).join("\n  ").trim();
  var fullMessage = `
Usage: ${ignoredBin} [script] [--flags]

Available Scripts:
  ${scriptsAvailableMessage}

Options:
  All options depend on the script. Docs will be improved eventually, but for most scripts you can assume that the args you pass will be forwarded to the respective tool that's being run under the hood.

May the force be with you.
  `.trim();
  console.log(`\n${fullMessage}\n`);
}

function getEnv() {
  // this is required to address an issue in cross-spawn
  // https://github.com/kentcdodds/kcd-scripts/issues/4
  return Object.keys(process.env).filter(function (key) {
    return process.env[key] !== undefined;
  }).reduce(function (envCopy, key) {
    envCopy[key] = process.env[key];
    return envCopy;
  }, {
    [`SCRIPTS_${script.toUpperCase()}`]: true
  });
}

function spawnScript() {
  var relativeScriptPath = _path.default.join(__dirname, "./scripts", script);

  var scriptPath = attemptResolve(relativeScriptPath);

  if (!scriptPath) {
    throw new Error(`Unknown script "${script}".`);
  }

  var result = _crossSpawn.default.sync(executor, [scriptPath].concat(args), {
    stdio: "inherit",
    env: getEnv()
  });

  if (result.signal) {
    handleSignal(result);
  } else {
    process.exit(result.status);
  }
}

function handleSignal(result) {
  if (result.signal === "SIGKILL") {
    console.log(`The script "${script}" failed because the process exited too early. ` + "This probably means the system ran out of memory or someone called " + "`kill -9` on the process.");
  } else if (result.signal === "SIGTERM") {
    console.log(`The script "${script}" failed because the process exited too early. ` + "Someone might have called `kill` or `killall`, or the system could " + "be shutting down.");
  }

  process.exit(1);
}

function attemptResolve() {
  try {
    return require.resolve.apply(void 0, arguments);
  } catch (error) {
    return null;
  }
}
//# sourceMappingURL=run-script.js.map