"use strict";

exports.__esModule = true;
exports.envIsSet = exports.parseEnv = exports.ifAnyDep = exports.hasPkgProp = exports.hasFile = exports.fromRoot = exports.resolveBin = exports.appDirectory = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _arrify = _interopRequireDefault(require("arrify"));

var _lodash = _interopRequireDefault(require("lodash.has"));

var _readPkgUp = _interopRequireDefault(require("read-pkg-up"));

var _which = _interopRequireDefault(require("which"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _readPkgUp$sync = _readPkgUp.default.sync({
  cwd: _fs.default.realpathSync(process.cwd())
}),
    pkg = _readPkgUp$sync.pkg,
    pkgPath = _readPkgUp$sync.path;

var appDirectory = _path.default.dirname(pkgPath);

exports.appDirectory = appDirectory;

var resolveBin = function (modName, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$executable = _ref.executable,
      executable = _ref$executable === void 0 ? modName : _ref$executable,
      _ref$cwd = _ref.cwd,
      cwd = _ref$cwd === void 0 ? process.cwd() : _ref$cwd;

  var pathFromWhich;

  try {
    pathFromWhich = _fs.default.realpathSync(_which.default.sync(executable));
  } catch (_error) {// ignore _error
  }

  try {
    var modPkgPath = require.resolve(`${modName}/package.json`);

    console.log(modName);

    var modPkgDir = _path.default.dirname(modPkgPath);

    var _require = require(modPkgPath),
        bin = _require.bin;

    var binPath = typeof bin === "string" ? bin : bin[executable];

    var fullPathToBin = _path.default.join(modPkgDir, binPath);

    if (fullPathToBin === pathFromWhich) {
      return executable;
    }

    return fullPathToBin.replace(cwd, ".");
  } catch (error) {
    if (pathFromWhich) {
      return executable;
    }

    throw error;
  }
};

exports.resolveBin = resolveBin;

var fromRoot = function () {
  for (var _len = arguments.length, p = new Array(_len), _key = 0; _key < _len; _key++) {
    p[_key] = arguments[_key];
  }

  return _path.default.join.apply(_path.default, [appDirectory].concat(p));
};

exports.fromRoot = fromRoot;

var hasFile = function () {
  return _fs.default.existsSync(fromRoot.apply(void 0, arguments));
};

exports.hasFile = hasFile;

var hasPkgProp = function (props) {
  return (0, _arrify.default)(props).some(function (prop) {
    return (0, _lodash.default)(pkg, prop);
  });
};

exports.hasPkgProp = hasPkgProp;

var hasPkgSubProp = function (pkgProp) {
  return function (props) {
    return hasPkgProp((0, _arrify.default)(props).map(function (p) {
      return `${pkgProp}.${p}`;
    }));
  };
};

var hasPeerDep = hasPkgSubProp("peerDependencies");
var hasDep = hasPkgSubProp("dependencies");
var hasDevDep = hasPkgSubProp("devDependencies");

var hasAnyDep = function (args) {
  return [hasDep, hasDevDep, hasPeerDep].some(function (fn) {
    return fn(args);
  });
};

var ifAnyDep = function (deps, t, f) {
  return hasAnyDep((0, _arrify.default)(deps)) ? t : f;
};

exports.ifAnyDep = ifAnyDep;

var parseEnv = function (name, def) {
  if (envIsSet(name)) {
    try {
      return JSON.parse(process.env[name]);
    } catch (err) {
      return process.env[name];
    }
  }

  return def;
};

exports.parseEnv = parseEnv;

var envIsSet = function (name) {
  return process.env.hasOwnProperty(name) && process.env[name] && process.env[name] !== "undefined";
};

exports.envIsSet = envIsSet;
//# sourceMappingURL=utils.js.map